/*
Package cryptobyte is a copy of the golang.org/x/crypto/cryptobyte package.

The cryptobyte package was copied over so that there's no dependency on
golang.org/x/crypto. No changes were made, except for the import path.

The package solely exists to support the legacy X509 certificate parser
functionality, which depends on cryptobyte.
*/

package cryptobyte
